/*
 * FindBugs - Find bugs in Java programs
 *
 * (C) Copyright 2005 Diomidis Spinellis <dds@aueb.gr>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: VerifyResult.java,v 1.1.1.1 2005/07/29 09:20:42 dds Exp $
 */

package edu.umd.cs.findbugs.apiv;

/**
 * Results returned from the API verification invocations.
 *
 * @see edu.umd.cs.findbugs.detect.ApiVerify
 * @author  Diomidis Spinellis
 * @version $Revision: 1.1.1.1 $
 */
public class VerifyResult {
    /** Result from an API verification call */
    public enum Value {
    UNVERIFIED,		// None of the method's arguments could not be verified
    PART_VERIFIED,	// The target objector some the method's arguments are correct
    ARG_VERIFIED,	// All the method's arguments are correct
    CORRECT,		// The method's invocation is correct
    ARGUMENT_ERROR,	// A discrete argument's value is incorrect
    DOMAIN_ERROR,	// A continous value is outside the allowable domain
    NAME_ERROR,		// The specified name is incorrect
    SYNTAX_ERROR	// A (String) argument's syntax is wrong
    }

    /** Qualify a correct result according to the argument constants. */
    public static Value qualifiedCorrect(boolean isConstant[]) {
	int sum = 0;
	for (int i = 1; i < isConstant.length; i++)
	    sum++;
	if (sum + 1 == isConstant.length)
	    return isConstant[0] ? Value.CORRECT : Value.ARG_VERIFIED;
	else if (sum == 0)
	    return isConstant[0] ? Value.PART_VERIFIED : Value.UNVERIFIED;
	else
	    return Value.PART_VERIFIED;
    }
}
