/*
 * FindBugs - Find bugs in Java programs
 *
 * (C) Copyright 2005 Diomidis Spinellis <dds@aueb.gr>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: MathV.java,v 1.1.1.1 2005/07/29 09:20:42 dds Exp $
 */

package edu.umd.cs.findbugs.apiv.java.lang;
import edu.umd.cs.findbugs.apiv.VerifyResult;

/**
 * Generic API invocation verifier for java.lang.Math
 * Return DOMAIN_ERROR in all cases where a compile-time constant
 * can cause a function to return a NaN value.
 *
 * @see edu.umd.cs.findbugs.detect.ApiVerify
 * @author  Diomidis Spinellis
 * @version $Revision: 1.1.1.1 $
 */
public class MathV {
    public static VerifyResult.Value acos(boolean isConstant[], Math t, double x) {
	if (isConstant[1])
	    if (Math.abs(x) > 1)
		return VerifyResult.Value.DOMAIN_ERROR;
	    else
		return VerifyResult.Value.CORRECT;
	else
	    return VerifyResult.Value.UNVERIFIED;
    }

    public static VerifyResult.Value log(boolean isConstant[], Math t, double x) {
	if (isConstant[1])
	    if (x < 0)
		return VerifyResult.Value.DOMAIN_ERROR;
	    else
		return VerifyResult.Value.CORRECT;
	else
	    return VerifyResult.Value.UNVERIFIED;
    }

    public static VerifyResult.Value log10(boolean isConstant[], Math t, double x) {
	if (isConstant[1])
	    if (x < 0)
		return VerifyResult.Value.DOMAIN_ERROR;
	    else
		return VerifyResult.Value.CORRECT;
	else
	    return VerifyResult.Value.UNVERIFIED;
    }

    public static VerifyResult.Value sqrt(boolean isConstant[], Math t, double x) {
	if (isConstant[1])
	    if (x < 0)
		return VerifyResult.Value.DOMAIN_ERROR;
	    else
		return VerifyResult.Value.CORRECT;
	else
	    return VerifyResult.Value.UNVERIFIED;
    }

    public static VerifyResult.Value IEEERemainder(boolean isConstant[], Math t, double f1, double f2) {
	if (isConstant[2])
	    if (f2 == 0)
		return VerifyResult.Value.DOMAIN_ERROR;
	    else
		return VerifyResult.Value.CORRECT;
	else
	    return VerifyResult.Value.UNVERIFIED;
    }

    public static VerifyResult.Value pow(boolean isConstant[], Math t, double a, double b) {
	if (isConstant[1] && isConstant[2])
	    if (a < 0 && (Math.ceil(b) != b))
		return VerifyResult.Value.DOMAIN_ERROR;
	    else
		return VerifyResult.Value.CORRECT;
	else
	    return VerifyResult.Value.UNVERIFIED;
    }

    public static VerifyResult.Value log1p(boolean isConstant[], Math t, double x) {
	if (isConstant[1])
	    if (x < -1)
		return VerifyResult.Value.DOMAIN_ERROR;
	    else
		return VerifyResult.Value.CORRECT;
	else
	    return VerifyResult.Value.UNVERIFIED;
    }
}
