/*
 * FindBugs - Find bugs in Java programs
 *
 * (C) Copyright 2005 Diomidis Spinellis <dds@aueb.gr>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: StatementV.java,v 1.1 2005/07/31 09:37:12 panos Exp $
 */

package edu.umd.cs.findbugs.apiv.java.sql;
import edu.umd.cs.findbugs.apiv.VerifyResult;

import java.sql.Statement;
import java.io.StringReader;

/**
 * Generic API invocation verifier for java.sql.Statement.
 * Return SYNTAX_ERROR if the SQL argument is not a valid
 * ANSI SQL statement.
 *
 * @see edu.umd.cs.findbugs.detect.ApiVerify
 * @author  Panagiotis Louridas
 * @version $Revision: 1.1 $
 */
public class StatementV {
    public VerifyResult.Value execute(boolean isConstant[], Statement s,
        String sql) {
	if (isConstant[1]) {
            if (!sql.endsWith(";")) {
                sql += ";";
            }
            try {
                SqlSQL2Lexer lexer = new SqlSQL2Lexer(new StringReader(sql));
                SqlSQL2Parser parser = new SqlSQL2Parser(lexer);
                parser.sql_stmt();
            } catch (Exception ex) {
                return VerifyResult.Value.SYNTAX_ERROR;
            }
            return VerifyResult.Value.ARG_VERIFIED;
	} else
	    return VerifyResult.Value.UNVERIFIED;
    }

    public VerifyResult.Value execute(boolean isConstant[], Statement s,
        String sql, int autoGeneratedKeys) {
        return execute(isConstant, s, sql);
    }

    public VerifyResult.Value execute(boolean isConstant[], Statement s,
        String sql, int[] columnIndexes) {
        return execute(isConstant, s, sql);
    }

    public VerifyResult.Value execute(boolean isConstant[], Statement s,
        String sql, String[] columnNames) {
        return execute(isConstant, s, sql);
    }

    public VerifyResult.Value executeQuery(boolean isConstant[], Statement s,
        String sql) {
        return execute(isConstant, s, sql);
    }

    public VerifyResult.Value executeUpdate(boolean isConstant[], Statement s,
        String sql) {
        return execute(isConstant, s, sql);
    }

    public VerifyResult.Value executeUpdate(boolean isConstant[], Statement s,
        String sql, int autoGeneratedKeys) {
        return execute(isConstant, s, sql);
    }

    public VerifyResult.Value executeUpdate(boolean isConstant[], Statement s,
        String sql, int[] columnIndexes) {
        return execute(isConstant, s, sql);
    }

    public VerifyResult.Value executeUpdate(boolean isConstant[], Statement s,
        String sql, String[] columnNames) {
        return execute(isConstant, s, sql);
    }

}
