/*
 * FindBugs - Find bugs in Java programs
 *
 * (C) Copyright 2005 Diomidis Spinellis <dds@aueb.gr>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: PatternV.java,v 1.1.1.1 2005/07/29 09:20:43 dds Exp $
 */

package edu.umd.cs.findbugs.apiv.java.util.regex;
import edu.umd.cs.findbugs.apiv.VerifyResult;
import java.util.regex.*;

/**
 * Generic API invocation verifier for java.util.regex.Pattern
 * Return SYNTAX_ERROR for invalid regular expressions, and ARGUMENT_ERROR
 * in a number of other cases.
 *
 * @see edu.umd.cs.findbugs.detect.ApiVerify
 * @author  Diomidis Spinellis
 * @version $Revision: 1.1.1.1 $
 */
public class PatternV {
    public static VerifyResult.Value compile(boolean isConstant[], Pattern t, String regex) {
	if (!isConstant[1])
	    return VerifyResult.Value.UNVERIFIED;
	try {
	    Pattern p = Pattern.compile(regex);
	    return VerifyResult.Value.CORRECT;
	} catch (PatternSyntaxException e) {
	    return VerifyResult.Value.SYNTAX_ERROR;
	}
    }

    public static VerifyResult.Value compile(boolean isConstant[], Pattern t, String regex, int flags) {
	String tryRegex = isConstant[1] ? regex : "x";
	int tryFlags = isConstant[2] ? flags : 0;
	try {
	    Pattern p = Pattern.compile(tryRegex, tryFlags);
	    return VerifyResult.qualifiedCorrect(isConstant);
	} catch (PatternSyntaxException e) {
	    return VerifyResult.Value.SYNTAX_ERROR;
	} catch (IllegalArgumentException e) {
	    // XXX Could not make this happen with JRE 1.5.0_02-b09
	    return VerifyResult.Value.ARGUMENT_ERROR;
	}
    }

    public static VerifyResult.Value matches(boolean isConstant[], Pattern t, String regex, CharSequence input) {
	return compile(isConstant, t, regex);
    }
}
