/*
 * FindBugs - Find bugs in Java programs
 *
 * (C) Copyright 2005 Panagiotis Louridas <louridas@aueb.gr>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: XPathV.java,v 1.1 2005/08/05 16:17:27 panos Exp $
 */

package edu.umd.cs.findbugs.apiv.org.apache.xpath;
import edu.umd.cs.findbugs.apiv.VerifyResult;

/**
 * Generic API invocation verifier for org.apache.xpath.XPath
 * Return SYNTAX_ERROR for invalid xpath expressions, and
 * ARGUMENT_ERROR in a number of other cases.
 *
 * @see edu.umd.cs.findbugs.detect.ApiVerify
 * @author Panagiotis Louridas 
 * @version $Revision: 1.1 $
 */

import org.apache.xpath.XPath;
import org.w3c.dom.Node;
import org.apache.xml.utils.PrefixResolver;
import javax.xml.transform.SourceLocator;
import javax.xml.transform.ErrorListener;
import org.xml.sax.InputSource;
import javax.xml.xpath.XPathFactory;
import javax.xml.xpath.XPathExpressionException;

import java.io.StringReader;

public class XPathV {

    private static final String DUMMY_XML = "<xml/>";

    public VerifyResult.Value XPath(boolean isConstant[], XPath xpath,
        String expr, SourceLocator locator, PrefixResolver prefixResolver,
        int type) {
        if (!isConstant[1])
            return VerifyResult.Value.UNVERIFIED;
        try {
            javax.xml.xpath.XPath tester =
                XPathFactory.newInstance().newXPath();
            tester.evaluate(expr,
                new InputSource(new StringReader(DUMMY_XML)));
            return VerifyResult.Value.CORRECT;
        } catch (XPathExpressionException xpex) {
            return VerifyResult.Value.SYNTAX_ERROR;
        } catch (NullPointerException npex) {
	    return VerifyResult.Value.ARGUMENT_ERROR;
        }
    }

    public VerifyResult.Value XPath(boolean isConstant[], XPath xpath,
        String expr, SourceLocator locator, PrefixResolver prefixResolver,
        int type, ErrorListener errorListener) {
        return XPath(isConstant, xpath, expr, locator, prefixResolver,
            type);
    }
}
